@@ -13,7 +13,7 @@ test_that("ard_stack_hierarchical(variables)", {
         ADAE_small,
         variables = c(AESOC, AEDECOD),
         id = USUBJID,
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       )
   )
 
@@ -30,7 +30,7 @@ test_that("ard_stack_hierarchical(variables)", {
       ADAE_small,
       variables = c(AESOC, AEDECOD),
       id = USUBJID,
-      denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+      denominator = ADSL
     ),
     ignore_attr = TRUE
   )
@@ -39,10 +39,11 @@ test_that("ard_stack_hierarchical(variables)", {
   expect_equal(
     ard |> dplyr::filter(is.na(group1)) |> dplyr::select(-all_ard_group_n(1L)),
     ard_hierarchical(
-      ADAE_small |> dplyr::slice_tail(n = 1L, by = c("USUBJID", "TRTA", "AESOC")),
+      ADAE_small |>
+        dplyr::slice_tail(n = 1L, by = c("USUBJID", "TRTA", "AESOC")),
       variables = AESOC,
       id = USUBJID,
-      denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+      denominator = ADSL
     ),
     ignore_attr = TRUE
   )
@@ -56,7 +57,7 @@ test_that("ard_stack_hierarchical(variables) messaging removed obs", {
       ard_stack_hierarchical(
         variables = c(AESOC, AEDECOD),
         id = USUBJID,
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       )
   )
 
@@ -66,10 +67,8 @@ test_that("ard_stack_hierarchical(variables) messaging removed obs", {
         variables = c(AESOC, AEDECOD),
         id = USUBJID,
         by = TRTA,
-        denominator =
-          ADSL |>
-            dplyr::rename(TRTA = TRT01A) |>
-            dplyr::mutate(TRTA = ifelse(dplyr::row_number() == 1L, NA, TRTA))
+        denominator = ADSL |>
+          dplyr::mutate(TRTA = ifelse(dplyr::row_number() == 1L, NA, TRTA))
       )
   )
 })
@@ -82,7 +81,7 @@ test_that("ard_stack_hierarchical(variables) messaging", {
       ard_stack_hierarchical(
         variables = starts_with("xxxxx"),
         id = USUBJID,
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       )
   )
 
@@ -93,7 +92,7 @@ test_that("ard_stack_hierarchical(variables) messaging", {
       ard_stack_hierarchical(
         variables = c(AESOC, AEDECOD),
         id = starts_with("xxxxx"),
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       )
   )
 })
@@ -107,7 +106,7 @@ test_that("ard_stack_hierarchical(by)", {
         variables = c(AESOC, AEDECOD),
         by = TRTA,
         id = USUBJID,
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       )
   )
 
@@ -117,10 +116,14 @@ test_that("ard_stack_hierarchical(by)", {
     variables = c(AESOC, AEDECOD),
     by = TRTA,
     id = USUBJID,
-    denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+    denominator = ADSL
   ) |>
     cards::tidy_ard_row_order()
-  attr(ard_match, "args") <- list(by = "TRTA", variables = c("AESOC", "AEDECOD"), include = c("AESOC", "AEDECOD"))
+  attr(ard_match, "args") <- list(
+    by = "TRTA",
+    variables = c("AESOC", "AEDECOD"),
+    include = c("AESOC", "AEDECOD")
+  )
 
   expect_equal(
     ard |> dplyr::filter(!is.na(group2)),
@@ -135,10 +138,14 @@ test_that("ard_stack_hierarchical(by)", {
     variables = AESOC,
     by = TRTA,
     id = USUBJID,
-    denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+    denominator = ADSL
   ) |>
     cards::tidy_ard_row_order()
-  attr(ard_match, "args") <- list(by = "TRTA", variables = c("AESOC"), include = c("AESOC"))
+  attr(ard_match, "args") <- list(
+    by = "TRTA",
+    variables = c("AESOC"),
+    include = c("AESOC")
+  )
 
   expect_equal(
     ard |>
@@ -148,6 +155,17 @@ test_that("ard_stack_hierarchical(by)", {
       sort_ard_hierarchical("alphanumeric"),
     ignore_attr = TRUE
   )
+
+  # ARD with >2 `by` variables works
+  expect_silent(expect_message(
+    ard_stack_hierarchical(
+      cards::ADAE,
+      variables = c(AESOC, AEDECOD),
+      by = c(TRTA, TRTEMFL, AESEV),
+      id = USUBJID,
+      denominator = ADSL
+    )
+  ))
 })
 
 test_that("ard_stack_hierarchical(by) messaging", {
@@ -159,9 +177,24 @@ test_that("ard_stack_hierarchical(by) messaging", {
         variables = c(AESOC, AEDECOD),
         by = TRTA,
         id = USUBJID,
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       )
   )
+
+  # no messaging if `id` values are present in multiple levels of the `by` variables
+  expect_no_warning(
+    suppressMessages(
+      ard_stack_hierarchical(
+        data = ADAE |>
+          dplyr::bind_rows(ADAE |> dplyr::mutate(TRTA = "Total")),
+        variables = c(AESOC, AEDECOD),
+        by = c(TRTA, AESEV),
+        denominator = ADSL |>
+          dplyr::bind_rows(ADSL |> dplyr::mutate(TRTA = "Total")),
+        id = USUBJID
+      )
+    )
+  )
 })
 
 test_that("ard_stack_hierarchical(denominator) messaging", {
@@ -187,6 +220,33 @@ test_that("ard_stack_hierarchical(denominator) messaging", {
       id = USUBJID
     )
   )
+
+  # check denominator only keeps "by" and "id" variables
+  adsl_updated <-
+    cards::ADSL |>
+    dplyr::mutate(
+      REGION = "Asia",
+      COUNTRY = sample(c("CHN", "JPN", "PAK"), size = dplyr::n(), replace = TRUE)
+    )
+
+  expect_equal(
+    cards::ard_stack_hierarchical(
+      adsl_updated,
+      by = "ARM",
+      variable = c("REGION", "COUNTRY"),
+      id = "USUBJID",
+      denominator = adsl_updated
+    ),
+    cards::ard_stack_hierarchical(
+      adsl_updated,
+      by = "ARM",
+      variable = c("REGION", "COUNTRY"),
+      id = "USUBJID",
+      denominator = adsl_updated[c("USUBJID", "ARM")]
+    ),
+    ignore_attr = TRUE,
+    ignore_function_env = TRUE
+  )
 })
 
 # test the rates are correct for items like AESEV, where we want to tabulate the most severe AE within the hierarchies
@@ -197,7 +257,7 @@ test_that("ard_stack_hierarchical(by) with columns not in `denominator`", {
       variables = c(AESOC, AEDECOD),
       by = c(AESEV),
       id = USUBJID,
-      denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+      denominator = ADSL
     ),
     'Denominator set by number of rows in.*denominator.*data frame.' # styler: off
   )
@@ -208,7 +268,7 @@ test_that("ard_stack_hierarchical(by) with columns not in `denominator`", {
       variables = c(AESOC, AEDECOD),
       by = c(TRTA, AESEV),
       id = USUBJID,
-      denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+      denominator = ADSL
     ),
     'Denominator set by.*"TRTA".*column in .*denominator.*data frame.' # styler: off
   )
@@ -216,14 +276,21 @@ test_that("ard_stack_hierarchical(by) with columns not in `denominator`", {
   # check the rates for AEDECOD are correct
   ard_match <- ADAE_small |>
     dplyr::arrange(USUBJID, TRTA, AESOC, AEDECOD, AESEV) |>
-    dplyr::filter(.by = c(USUBJID, TRTA, AESOC, AEDECOD), dplyr::n() == dplyr::row_number()) |>
+    dplyr::filter(
+      .by = c(USUBJID, TRTA, AESOC, AEDECOD),
+      dplyr::n() == dplyr::row_number()
+    ) |>
     ard_hierarchical(
       variables = c(AESOC, AEDECOD),
       by = c(TRTA, AESEV),
-      denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+      denominator = ADSL
     ) |>
     tidy_ard_row_order()
-  attr(ard_match, "args") <- list(by = "TRTA", variables = c("AESOC", "AEDECOD", "AESEV"), include = c("AESOC", "AEDECOD", "AESEV"))
+  attr(ard_match, "args") <- list(
+    by = "TRTA",
+    variables = c("AESOC", "AEDECOD", "AESEV"),
+    include = c("AESOC", "AEDECOD", "AESEV")
+  )
 
   expect_equal(
     ard |>
@@ -237,14 +304,21 @@ test_that("ard_stack_hierarchical(by) with columns not in `denominator`", {
   # check the rates for AESOC are correct
   ard_match <- ADAE_small |>
     dplyr::arrange(USUBJID, TRTA, AESOC, AESEV) |>
-    dplyr::filter(.by = c(USUBJID, TRTA, AESOC), dplyr::n() == dplyr::row_number()) |>
+    dplyr::filter(
+      .by = c(USUBJID, TRTA, AESOC),
+      dplyr::n() == dplyr::row_number()
+    ) |>
     ard_hierarchical(
       variables = AESOC,
       by = c(TRTA, AESEV),
-      denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+      denominator = ADSL
     ) |>
     tidy_ard_row_order()
-  attr(ard_match, "args") <- list(by = "TRTA", variables = c("AESOC", "AESEV"), include = c("AESOC", "AESEV"))
+  attr(ard_match, "args") <- list(
+    by = "TRTA",
+    variables = c("AESOC", "AESEV"),
+    include = c("AESOC", "AESEV")
+  )
 
   expect_equal(
     ard |>
@@ -266,7 +340,7 @@ test_that("ard_stack_hierarchical(variables, include) messaging", {
       variables = c(AESOC, AEDECOD),
       include = AESOC,
       by = TRTA,
-      denominator = ADSL |> dplyr::rename(TRTA = ARM),
+      denominator = ADSL,
       id = USUBJID
     )
   )
@@ -277,7 +351,7 @@ test_that("ard_stack_hierarchical(by, overall) messaging", {
     ard <- ard_stack_hierarchical(
       ADAE_small,
       variables = c(AESOC, AEDECOD),
-      denominator = ADSL |> dplyr::rename(TRTA = ARM),
+      denominator = ADSL,
       id = USUBJID,
       overall = TRUE
     )
@@ -289,14 +363,14 @@ test_that("ard_stack_hierarchical(statistic)", {
     ard_stack_hierarchical(
       ADAE,
       variables = AESOC,
-      denominator = ADSL |> dplyr::rename(TRTA = ARM),
+      denominator = ADSL,
       id = USUBJID,
       statistic = everything() ~ "p"
     ),
     ard_stack_hierarchical(
       ADAE,
       variables = AESOC,
-      denominator = ADSL |> dplyr::rename(TRTA = ARM),
+      denominator = ADSL,
       id = USUBJID,
       statistic = everything() ~ c("n", "N", "p")
     ) |>
@@ -304,6 +378,20 @@ test_that("ard_stack_hierarchical(statistic)", {
   )
 })
 
+test_that("ard_stack_hierarchical with shuffle", {
+  # we expect it to work but with a warning messaged related to the deprecation
+  # of the `shuffle` argument
+  expect_error(
+    ard_shuffled <- ard_stack_hierarchical(
+      ADAE_small,
+      variables = c(AESOC, AEDECOD),
+      id = USUBJID,
+      denominator = ADSL,
+      shuffle = TRUE
+    )
+  )
+})
+
 # ard_stack_hierarchical_count() -----------------------------------------------
 test_that("ard_stack_hierarchical_count(variables)", {
   # ensure that all nested variables appear in resulting ARD
@@ -323,7 +411,11 @@ test_that("ard_stack_hierarchical_count(variables)", {
 
   # check AEDECOD match
   ard_match <- ard_hierarchical_count(ADAE_small, variables = c(AESOC, AEDECOD))
-  attr(ard_match, "args") <- list(by = NULL, variables = c("AESOC", "AEDECOD"), include = c("AESOC", "AEDECOD"))
+  attr(ard_match, "args") <- list(
+    by = NULL,
+    variables = c("AESOC", "AEDECOD"),
+    include = c("AESOC", "AEDECOD")
+  )
 
   expect_equal(
     ard |> dplyr::filter(!is.na(group1)),
@@ -333,7 +425,11 @@ test_that("ard_stack_hierarchical_count(variables)", {
 
   # check AESOC match
   ard_match <- ard_hierarchical_count(ADAE_small, variables = AESOC)
-  attr(ard_match, "args") <- list(by = NULL, variables = "AESOC", include = "AESOC")
+  attr(ard_match, "args") <- list(
+    by = NULL,
+    variables = "AESOC",
+    include = "AESOC"
+  )
 
   expect_equal(
     ard |> dplyr::filter(is.na(group1)) |> dplyr::select(-all_ard_group_n(1L)),
@@ -355,13 +451,22 @@ test_that("ard_stack_hierarchical_count(by)", {
   # check the number of rows is expected
   expect_equal(
     nrow(ard),
-    (length(unique(ADAE_small$AESOC)) + length(unique(ADAE_small$AEDECOD))) * length(unique(ADAE_small$TRTA))
+    (length(unique(ADAE_small$AESOC)) + length(unique(ADAE_small$AEDECOD))) *
+      length(unique(ADAE_small$TRTA))
   )
 
   # check AEDECOD match
-  ard_match <- ard_hierarchical_count(ADAE_small, variables = c(AESOC, AEDECOD), by = TRTA) |>
+  ard_match <- ard_hierarchical_count(
+    ADAE_small,
+    variables = c(AESOC, AEDECOD),
+    by = TRTA
+  ) |>
     cards::tidy_ard_row_order()
-  attr(ard_match, "args") <- list(by = "TRTA", variables = c("AESOC", "AEDECOD"), include = c("AESOC", "AEDECOD"))
+  attr(ard_match, "args") <- list(
+    by = "TRTA",
+    variables = c("AESOC", "AEDECOD"),
+    include = c("AESOC", "AEDECOD")
+  )
 
   expect_equal(
     ard |> dplyr::filter(!is.na(group2)),
@@ -370,9 +475,17 @@ test_that("ard_stack_hierarchical_count(by)", {
   )
 
   # check AESOC match
-  ard_match <- ard_hierarchical_count(ADAE_small, variables = AESOC, by = TRTA) |>
+  ard_match <- ard_hierarchical_count(
+    ADAE_small,
+    variables = AESOC,
+    by = TRTA
+  ) |>
     cards::tidy_ard_row_order()
-  attr(ard_match, "args") <- list(by = "TRTA", variables = "AESOC", include = "AESOC")
+  attr(ard_match, "args") <- list(
+    by = "TRTA",
+    variables = "AESOC",
+    include = "AESOC"
+  )
 
   expect_equal(
     ard |> dplyr::filter(is.na(group2)) |> dplyr::select(-all_ard_group_n(2L)),
@@ -401,27 +514,26 @@ test_that("ard_stack_hierarchical_count(denominator) univariate tabulations", {
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
         by = TRTA,
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       ) |>
       dplyr::filter(variable == "TRTA") |>
       dplyr::select(-all_missing_columns()),
-    ard_categorical(ADSL |> dplyr::rename(TRTA = TRT01A), variables = TRTA) |>
+    ard_tabulate(ADSL, variables = TRTA) |>
       dplyr::select(-all_missing_columns()),
     ignore_attr = TRUE
   )
 
-
   # everything still works when the by variable includes vars not in the denom data frame
   expect_equal(
     ard <- ADAE_small |>
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
         by = c(TRTA, AESEV),
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A)
+        denominator = ADSL
       ) |>
       dplyr::filter(variable == "TRTA") |>
       dplyr::select(-all_missing_columns()),
-    ard_categorical(ADSL |> dplyr::rename(TRTA = TRT01A), variables = TRTA) |>
+    ard_tabulate(ADSL, variables = TRTA) |>
       dplyr::select(-all_missing_columns()),
     ignore_attr = TRUE
   )
@@ -434,7 +546,7 @@ test_that("ard_stack_hierarchical_count(denominator,total_n)", {
     ADAE_small |>
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
-        denominator = ADSL |> dplyr::rename(TRTA = TRT01A),
+        denominator = ADSL,
         total_n = TRUE
       ) |>
       dplyr::filter(variable == "..ard_total_n..") |>
@@ -484,7 +596,6 @@ test_that("ard_stack_hierarchical_count(overall, denominator) messaging", {
 })
 
 
-
 test_that("ard_stack_hierarchical_count(overall)", {
   withr::local_options(list(width = 250))
   # requesting overall without a data frame denominator
@@ -493,15 +604,17 @@ test_that("ard_stack_hierarchical_count(overall)", {
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
         by = TRTA,
-        denominator = ADSL |> dplyr::rename(TRTA = ARM),
+        denominator = ADSL,
         overall = TRUE
       ) |>
-      dplyr::filter(!group1 %in% "TRTA" & !group2 %in% "TRTA" & !variable %in% "TRTA") |>
+      dplyr::filter(
+        !group1 %in% "TRTA" & !group2 %in% "TRTA" & !variable %in% "TRTA"
+      ) |>
       dplyr::select(-all_missing_columns()),
     ADAE_small |>
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
-        denominator = ADSL |> dplyr::rename(TRTA = ARM)
+        denominator = ADSL
       ) |>
       dplyr::select(-all_missing_columns()),
     ignore_attr = TRUE
@@ -514,10 +627,15 @@ test_that("ard_stack_hierarchical_count(overall)", {
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
         by = c(TRTA, AESEV),
-        denominator = ADSL |> dplyr::rename(TRTA = ARM),
+        denominator = ADSL,
         overall = TRUE
       ) |>
-      dplyr::filter(!group1 %in% "TRTA" & !group2 %in% "TRTA" & !group3 %in% "TRTA" & !variable %in% "TRTA")
+      dplyr::filter(
+        !group1 %in% "TRTA" &
+          !group2 %in% "TRTA" &
+          !group3 %in% "TRTA" &
+          !variable %in% "TRTA"
+      )
   })
 })
 
@@ -528,7 +646,7 @@ test_that("ard_stack_hierarchical_count(over_variables)", {
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
         by = TRTA,
-        denominator = ADSL |> dplyr::rename(TRTA = ARM),
+        denominator = ADSL,
         over_variables = TRUE
       ) |>
       dplyr::filter(variable %in% "..ard_hierarchical_overall..") |>
@@ -538,7 +656,7 @@ test_that("ard_stack_hierarchical_count(over_variables)", {
       ard_stack_hierarchical_count(
         variables = ..ard_hierarchical_overall..,
         by = TRTA,
-        denominator = ADSL |> dplyr::rename(TRTA = ARM)
+        denominator = ADSL
       ) |>
       dplyr::filter(variable %in% "..ard_hierarchical_overall..") |>
       dplyr::select(-all_missing_columns()),
@@ -547,13 +665,14 @@ test_that("ard_stack_hierarchical_count(over_variables)", {
 })
 
 test_that("ard_stack_hierarchical_count(overall,over_variables)", {
+  withr::local_options(list(width = 250))
   # ensuring we have an overall row grouped by TRTA, and across TRTA levels (nrow=4)
   expect_snapshot(
     ADAE_small |>
       ard_stack_hierarchical_count(
         variables = AESOC,
         by = TRTA,
-        denominator = ADSL |> dplyr::rename(TRTA = ARM),
+        denominator = ADSL,
         over_variables = TRUE,
         overall = TRUE
       ) |>
@@ -561,8 +680,25 @@ test_that("ard_stack_hierarchical_count(overall,over_variables)", {
       dplyr::select(all_ard_groups(), "variable", "stat_name", "stat") |>
       as.data.frame()
   )
-})
 
+  # both `overall=TRUE` and `over_variables=TRUE` work together with multiple `by` variables present
+  expect_snapshot({
+    ADAE_small |>
+      ard_stack_hierarchical_count(
+        variables = c(AESOC, AEDECOD),
+        by = c(TRTA, AESEV),
+        denominator = ADSL,
+        overall = TRUE,
+        over_variables = TRUE
+      ) |>
+      dplyr::filter(
+        !group1 %in% "TRTA" &
+          !group2 %in% "TRTA" &
+          !group3 %in% "TRTA" &
+          !variable %in% "TRTA"
+      )
+  })
+})
 
 test_that("ard_stack_hierarchical_count(attributes)", {
   # requesting overall without a data frame denominator
@@ -571,15 +707,56 @@ test_that("ard_stack_hierarchical_count(attributes)", {
       ard_stack_hierarchical_count(
         variables = c(AESOC, AEDECOD),
         by = TRTA,
-        denominator = ADSL |> dplyr::rename(TRTA = ARM),
+        denominator = ADSL,
         attributes = TRUE
       ) |>
       dplyr::filter(context %in% "attributes") |>
       dplyr::select(-all_missing_columns()),
     ADAE_small |>
       ard_attributes(variables = c(TRTA, AESOC, AEDECOD)) |>
-      dplyr::select(-all_missing_columns()) |>
-      dplyr::slice(c(5:6, 1:2, 3:4)),
+      dplyr::select(-all_missing_columns()),
     ignore_attr = TRUE
   )
 })
+
+test_that("ard_stack_hierarchical() by_stats argument", {
+  # include by_stats
+  expect_silent(
+    ard <-
+      ard_stack_hierarchical(
+        ADAE_small,
+        variables = c(AESOC, AEDECOD),
+        by = TRTA,
+        id = USUBJID,
+        denominator = ADSL,
+        by_stats = TRUE
+      )
+  )
+
+  expect_equal(
+    ard |> dplyr::filter(variable == "TRTA") |> dplyr::select(-all_ard_groups()),
+    ard_tabulate(
+      data = ADSL,
+      variables = TRTA
+    ),
+    ignore_attr = TRUE
+  )
+
+  # no by_stats
+  expect_silent(
+    ard <-
+      ard_stack_hierarchical(
+        ADAE_small,
+        variables = c(AESOC, AEDECOD),
+        by = TRTA,
+        id = USUBJID,
+        denominator = ADSL,
+        by_stats = FALSE
+      )
+  )
+
+  expect_equal(
+    ard |> dplyr::filter(variable == "TRTA") |> nrow(),
+    0
+  )
+})
