@@ -1,6 +1,6 @@
 test_that("as_nested_list() works", {
   expect_snapshot(
-    ard_continuous(mtcars, by = "cyl", variables = "hp") |>
+    ard_summary(mtcars, by = "cyl", variables = "hp") |>
       as_nested_list()
   )
 })
