@@ -1,6 +1,6 @@
 test_that("check_ard_structure() works", {
   expect_snapshot(
-    ard_continuous(ADSL, variables = "AGE") |>
+    ard_summary(ADSL, variables = "AGE") |>
       dplyr::mutate(stat = unlist(stat)) |>
       dplyr::select(-error) |>
       structure(class = "data.frame") |>
