@@ -1,13 +1,13 @@
-skip_if_not(is_pkg_installed("withr"))
+skip_if_pkg_not_installed("withr")
 
 test_that("options(cards.round_type)", {
-  # test that the p is rounded to zero (ie rounded to even) for aliases called by `apply_fmt_fn()`
+  # test that the p is rounded to zero (ie rounded to even) for aliases called by `apply_fmt_fun()`
   withr::local_options(list(cards.round_type = "round-to-even"))
   expect_equal(
     data.frame(x = c(T, F)) |>
-      ard_categorical(variables = everything(), statistic = ~"p") |>
-      update_ard_fmt_fn(stat_names = "p", fmt_fn = 0) |>
-      apply_fmt_fn() |>
+      ard_tabulate(variables = everything(), statistic = ~"p") |>
+      update_ard_fmt_fun(stat_names = "p", fmt_fun = 0) |>
+      apply_fmt_fun() |>
       dplyr::pull("stat_fmt") |>
       unique() |>
       unlist(),
@@ -17,8 +17,8 @@ test_that("options(cards.round_type)", {
   # test that the p is rounded to zero (ie rounded to even) for default fmt functions
   expect_equal(
     data.frame(x = rep_len(TRUE, 1999) |> c(FALSE)) |>
-      ard_categorical(variables = everything(), statistic = ~"p") |>
-      apply_fmt_fn() |>
+      ard_tabulate(variables = everything(), statistic = ~"p") |>
+      apply_fmt_fun() |>
       dplyr::filter(variable_level %in% FALSE) |>
       dplyr::pull("stat_fmt") |>
       unlist(),
@@ -33,7 +33,7 @@ test_that("options(cards.round_type) messaging", {
     withr::with_options(
       list(cards.round_type = "NOT-CORRECT"),
       data.frame(x = c(T, F)) |>
-        ard_categorical(variables = everything(), statistic = ~"p")
+        ard_tabulate(variables = everything(), statistic = ~"p")
     )
   )
 })
