@@ -1,5 +1,5 @@
 test_that("tidy_ard_row_order() works", {
-  skip_if_not(is_pkg_installed("withr"))
+  skip_if_pkg_not_installed("withr")
   withr::local_options(list(width = 120))
   withr::local_seed(1)
 
@@ -12,7 +12,7 @@ test_that("tidy_ard_row_order() works", {
       zz = 1L,
       aa = 1L
     ) |>
-      ard_categorical(
+      ard_tabulate(
         by = x1:x3,
         variables = c(zz, aa),
         statistic = everything() ~ "n"
